import{A as e,b as a,j as t,c as r,G as o}from"./index.BdH_oWMm.js";import{P as l}from"./ProgressBar.CRZKgbuK.js";const i=e("div",{target:"e1jwj65h0"})(({theme:s})=>({paddingBottom:s.spacing.sm,lineHeight:"normal"}));function d({element:s}){return t("div",{className:"stProgress","data-testid":"stProgress",children:[r(i,{children:r(o,{source:s.text,allowHTML:!1,isLabel:!0})}),r(l,{value:s.value})]})}const g=a.memo(d);export{g as default};
