import{A as r}from"./index.BdH_oWMm.js";const o=r("div",{target:"e1d7a4qp0"})(({theme:i,$isHighlighted:d})=>({flexGrow:1,display:"flex",alignItems:"center",paddingLeft:i.spacing.sm,paddingRight:i.spacing.sm,height:i.sizes.elementHighlightHeight,borderTopLeftRadius:i.radii.md2,borderTopRightRadius:i.radii.md2,borderBottomRightRadius:i.radii.md2,borderBottomLeftRadius:i.radii.md2,background:d?i.colors.darkenedBgMix15:"transparent",transition:"background 50ms ease","&:hover, &:active, &:focus-visible":{background:i.colors.darkenedBgMix15}}));export{o as S};
