import{b as g,c as t,A as a,bj as d}from"./index.BdH_oWMm.js";import{S as l}from"./styled-components.BwP7eYqe.js";import{a as p}from"./select.ox5FKmP0.js";function f(i){const r=g.forwardRef(({children:e,$isHighlighted:s,...o},n)=>t(i,{ref:n,...o,children:t(l,{$isHighlighted:s,children:e})}));return r.displayName=`HighlightListItem(${i.displayName||i.name||"Component"})`,r}const u=a("div",{target:"e1bzcuw60"})({position:"absolute",top:"50%",right:"2.05em"}),y=a(p,{shouldForwardProp:d,target:"e1bzcuw61"})(({theme:i})=>({position:"relative",display:"flex",alignItems:"center",padding:i.spacing.none,margin:i.spacing.none,height:i.sizes.dropdownItemHeight,marginLeft:i.sizes.tagMarginInsideBorder,marginRight:`max(0px, calc(${i.sizes.tagMarginInsideBorder} - var(--scrollbar-gutter-size, 0px)))`,background:"transparent",fontWeight:i.fontWeights.normal}));export{y as S,u as a,f as c};
