import{c as e,cz as n,aG as s,cA as b}from"./index.BdH_oWMm.js";import{b as m}from"./styled-components.jdcyFPSS.js";function L({content:a,label:l,ariaLabel:o,placement:t=s.TOP_RIGHT,isLatex:i,markdownProps:r,onMouseEnterDelay:c,containerWidth:p}){return e(m,{children:e(n,{content:a,placement:t,isLatex:i,markdownProps:r,onMouseEnterDelay:c,containerWidth:p,ariaLabel:o??b(l)})})}export{L as W};
