import{b as e,aW as l,aX as p,c as s,ai as x,A as C,am as f,D as g}from"./index.BdH_oWMm.js";const M=({children:t})=>{const a=e.useContext(l)?.();return a?p.createPortal(t,a):s(x,{children:t})},P=C("div",{target:"e1smm6vf0"})({"@media print":{display:"none"}}),u=({className:t,scriptRunId:a,numParticles:o,numParticleTypes:r,ParticleComponent:n})=>{const{resourceCrossOriginMode:i}=e.useContext(f),c=e.useMemo(()=>g(o).map(()=>Math.floor(Math.random()*r)),[o,r]);return s(P,{className:t,"data-testid":t,children:c.map((m,d)=>s(n,{particleType:m,resourceCrossOriginMode:i},a+d))})},y=e.memo(u);export{y as P,M as R};
