const a=["allow-forms","allow-modals","allow-popups","allow-popups-to-escape-sandbox","allow-same-origin","allow-scripts","allow-downloads"].join(" "),o=["accelerometer","ambient-light-sensor","autoplay","battery","camera","clipboard-write","document-domain","encrypted-media","fullscreen","geolocation","gyroscope","layout-animations","legacy-image-formats","magnetometer","microphone","midi","oversized-images","payment","picture-in-picture","publickey-credentials-get","sync-xhr","usb","vr ","wake-lock","xr-spatial-tracking"].join("; ");export{a as D,o as a};
