import{ct as a}from"./index.BdH_oWMm.js";const s=({enforceDownloadInNewTab:n,url:e,filename:o})=>{const t=document.createElement("a");t.setAttribute("href",e),n?t.setAttribute("target","_blank"):t.setAttribute("target","_self");const r=a.DOWNLOAD_ASSETS_BASE_URL;return(!r||!e.startsWith(r)||window.navigator.userAgent.includes("Firefox"))&&t.setAttribute("download",o),t};export{s as c};
