import{A as s,b as t,U as i,c as d,i as c}from"./index.BdH_oWMm.js";import{D as e,a as l}from"./IFrameUtil.DefezniK.js";const m=s("iframe",{target:"eu9re3w0"})(({theme:o,disableScrolling:r})=>({width:"100%",height:"100%",colorScheme:"normal",border:"none",padding:o.spacing.none,margin:o.spacing.none,overflow:r?"hidden":void 0}));function a(o){return c(o)||o===""?void 0:o}function f({element:o}){const r=a(o.src),n=i(r)?void 0:a(o.srcdoc);return d(m,{className:"stIFrame","data-testid":"stIFrame",allow:l,disableScrolling:!o.scrolling,src:r,srcDoc:n,scrolling:o.scrolling?"auto":"no",sandbox:e,title:"st.iframe",tabIndex:o.tabIndex??void 0})}const F=t.memo(f);export{F as default};
