"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import LabelVisibility_pb2 as _LabelVisibility_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class TextInput(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _Type:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _TypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[TextInput._Type.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DEFAULT: TextInput._Type.ValueType  # 0
        """A normal text input."""
        PASSWORD: TextInput._Type.ValueType  # 1
        """A password text input. Typed values are obscured by default."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    DEFAULT: TextInput.Type.ValueType  # 0
    """A normal text input."""
    PASSWORD: TextInput.Type.ValueType  # 1
    """A password text input. Typed values are obscured by default."""

    ID_FIELD_NUMBER: _builtins.int
    LABEL_FIELD_NUMBER: _builtins.int
    DEFAULT_FIELD_NUMBER: _builtins.int
    TYPE_FIELD_NUMBER: _builtins.int
    MAX_CHARS_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    FORM_ID_FIELD_NUMBER: _builtins.int
    VALUE_FIELD_NUMBER: _builtins.int
    SET_VALUE_FIELD_NUMBER: _builtins.int
    AUTOCOMPLETE_FIELD_NUMBER: _builtins.int
    PLACEHOLDER_FIELD_NUMBER: _builtins.int
    DISABLED_FIELD_NUMBER: _builtins.int
    LABEL_VISIBILITY_FIELD_NUMBER: _builtins.int
    ICON_FIELD_NUMBER: _builtins.int
    QUERY_PARAM_KEY_FIELD_NUMBER: _builtins.int
    id: _builtins.str
    label: _builtins.str
    default: _builtins.str
    type: Global___TextInput.Type.ValueType
    max_chars: _builtins.int
    help: _builtins.str
    form_id: _builtins.str
    value: _builtins.str
    set_value: _builtins.bool
    autocomplete: _builtins.str
    placeholder: _builtins.str
    disabled: _builtins.bool
    icon: _builtins.str
    query_param_key: _builtins.str
    """If set, widget value is bound to this query parameter key"""
    @_builtins.property
    def label_visibility(self) -> _LabelVisibility_pb2.LabelVisibility: ...
    def __init__(
        self,
        *,
        id: _builtins.str = ...,
        label: _builtins.str = ...,
        default: _builtins.str | None = ...,
        type: Global___TextInput.Type.ValueType = ...,
        max_chars: _builtins.int = ...,
        help: _builtins.str = ...,
        form_id: _builtins.str = ...,
        value: _builtins.str | None = ...,
        set_value: _builtins.bool = ...,
        autocomplete: _builtins.str = ...,
        placeholder: _builtins.str = ...,
        disabled: _builtins.bool = ...,
        label_visibility: _LabelVisibility_pb2.LabelVisibility | None = ...,
        icon: _builtins.str = ...,
        query_param_key: _builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_default", b"_default", "_query_param_key", b"_query_param_key", "_value", b"_value", "default", b"default", "label_visibility", b"label_visibility", "query_param_key", b"query_param_key", "value", b"value"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_default", b"_default", "_query_param_key", b"_query_param_key", "_value", b"_value", "autocomplete", b"autocomplete", "default", b"default", "disabled", b"disabled", "form_id", b"form_id", "help", b"help", "icon", b"icon", "id", b"id", "label", b"label", "label_visibility", b"label_visibility", "max_chars", b"max_chars", "placeholder", b"placeholder", "query_param_key", b"query_param_key", "set_value", b"set_value", "type", b"type", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__default: _TypeAlias = _typing.Literal["default"]  # noqa: Y015
    _WhichOneofArgType__default: _TypeAlias = _typing.Literal["_default", b"_default"]  # noqa: Y015
    _WhichOneofReturnType__query_param_key: _TypeAlias = _typing.Literal["query_param_key"]  # noqa: Y015
    _WhichOneofArgType__query_param_key: _TypeAlias = _typing.Literal["_query_param_key", b"_query_param_key"]  # noqa: Y015
    _WhichOneofReturnType__value: _TypeAlias = _typing.Literal["value"]  # noqa: Y015
    _WhichOneofArgType__value: _TypeAlias = _typing.Literal["_value", b"_value"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__default) -> _WhichOneofReturnType__default | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__query_param_key) -> _WhichOneofReturnType__query_param_key | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__value) -> _WhichOneofReturnType__value | None: ...

Global___TextInput: _TypeAlias = TextInput  # noqa: Y015
