import{J as o}from"./index.BdH_oWMm.js";const i={[o.ButtonLikeIconPosition.LEFT]:"left",[o.ButtonLikeIconPosition.RIGHT]:"right"};function r(t){return i[t??o.ButtonLikeIconPosition.LEFT]}export{r as m};
