import{c as e,cz as p,aG as s,cA as m}from"./index.BdH_oWMm.js";import{a as I}from"./styled-components.jdcyFPSS.js";function H({content:a,label:l,ariaLabel:i,placement:o=s.TOP_RIGHT,isLatex:t,markdownProps:n,onMouseEnterDelay:r,containerWidth:c}){return e(I,{children:e(p,{content:a,placement:o,isLatex:t,markdownProps:n,onMouseEnterDelay:r,containerWidth:c,ariaLabel:i??m(l)})})}export{H as W};
