import{i as d,c as e,ai as n,j as l,G as o}from"./index.BdH_oWMm.js";import{S as u}from"./styled-components.jdcyFPSS.js";function c({label:a,children:r,disabled:t,labelVisibility:i,htmlFor:s}){return d(a)?e(n,{}):l(u,{"data-testid":"stWidgetLabel",disabled:t,labelVisibility:i,htmlFor:s,children:[e("span",{"aria-hidden":"true",children:e(o,{source:a,allowHTML:!1,isLabel:!0})}),r]})}export{c as W};
