"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class LabelVisibility(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _LabelVisibilityOptions:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _LabelVisibilityOptionsEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[LabelVisibility._LabelVisibilityOptions.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        VISIBLE: LabelVisibility._LabelVisibilityOptions.ValueType  # 0
        HIDDEN: LabelVisibility._LabelVisibilityOptions.ValueType  # 1
        COLLAPSED: LabelVisibility._LabelVisibilityOptions.ValueType  # 2

    class LabelVisibilityOptions(_LabelVisibilityOptions, metaclass=_LabelVisibilityOptionsEnumTypeWrapper):
        """We use a separate LabelVisibility message instead of just defining an Enum
        and using it in other widgets proto files due to a protobuf.js error when
        just an enum is defined and imported.
        https://github.com/protobufjs/protobuf.js/issues/1414
        """

    VISIBLE: LabelVisibility.LabelVisibilityOptions.ValueType  # 0
    HIDDEN: LabelVisibility.LabelVisibilityOptions.ValueType  # 1
    COLLAPSED: LabelVisibility.LabelVisibilityOptions.ValueType  # 2

    VALUE_FIELD_NUMBER: _builtins.int
    value: Global___LabelVisibility.LabelVisibilityOptions.ValueType
    def __init__(
        self,
        *,
        value: Global___LabelVisibility.LabelVisibilityOptions.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LabelVisibility: _TypeAlias = LabelVisibility  # noqa: Y015
