"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

class _RootContainer:
    ValueType = _typing.NewType("ValueType", _builtins.int)
    V: _TypeAlias = ValueType  # noqa: Y015

class _RootContainerEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[_RootContainer.ValueType], _builtins.type):
    DESCRIPTOR: _descriptor.EnumDescriptor
    MAIN: _RootContainer.ValueType  # 0
    SIDEBAR: _RootContainer.ValueType  # 1
    EVENT: _RootContainer.ValueType  # 2
    BOTTOM: _RootContainer.ValueType  # 3

class RootContainer(_RootContainer, metaclass=_RootContainerEnumTypeWrapper):
    """Constants for our "RootContainers" - the top-level containers
    that `st.foo` and `st.sidebar.foo` write to. Each value corresponds
    to the first index in any `delta_path` that uses these containers.
    (This enum is not used in any protobuf messages; we declare it here so
    that the values remain synced between Python and the frontend.)
    """

MAIN: RootContainer.ValueType  # 0
SIDEBAR: RootContainer.ValueType  # 1
EVENT: RootContainer.ValueType  # 2
BOTTOM: RootContainer.ValueType  # 3
Global___RootContainer: _TypeAlias = RootContainer  # noqa: Y015
